nltk.metrics package
====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.metrics.agreement
   nltk.metrics.aline
   nltk.metrics.association
   nltk.metrics.confusionmatrix
   nltk.metrics.distance
   nltk.metrics.paice
   nltk.metrics.scores
   nltk.metrics.segmentation
   nltk.metrics.spearman

Module contents
---------------

.. automodule:: nltk.metrics
   :members:
   :undoc-members:
   :show-inheritance:
